from stkhelper import application, scenario, satellite

class Basic:
    """
    
    Basic test that opens a scenario, adds a satellite, and closes.
    
    """
    def __init__(self):
        app = application.Application()
        scene = scenario.Scenario(app,'Basic','+24hrs')
        sat = satellite.Satellite(scene,'TestSat',25544)
        
        input("Press enter to close test")
        
        scene.Close()
        app.Close()
        